@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import json
 
 
 class event_payload(object):
@@ -35,3 +36,15 @@ class event_payload(object):
             return self.__ts
         except AttributeError:
             return None
+
+    def __repr__(self):
+        dump = {}
+        if hasattr(self, "id"):
+            dump["id"] = self.id
+        if hasattr(self, "event_type"):
+            dump["event_type"] = self.event_type
+        if hasattr(self, "subject"):
+            dump["subject"] = f"type {type(self.subject).__name__}"
+        if hasattr(self, "ts") and self.ts is not None:
+            dump["ts"] = self.ts.isoformat()
+        return json.dumps(dump, sort_keys=True)
